#!/bin/sh
echo "Generating Haarte notation file for $1"
R --slave << EOF
  tryCatch(
    library("KSNR"),
  error=function(cond) {
    cat("KSNR package could not be loaded, trying to install it.\n")
    install.packages("KSNR_0.9.tar.gz", repos=NULL)
    library("KSNR")  # no error during installation, so it should load fine now
  })
  cat("Loading harmony data...\n")
  KSData = readKSFile("../Harmony/KSN/$1.ksn")
  cat("Converting to Harte labels...\n")
  HarteData = data.frame(KSData[,"Ticks"], KSData[,"BPM"], KSData[,"Beat"], rep(NA, nrow(KSData)))
  colnames(HarteData) = c("Ticks", "BPM", "Beats", "Chord")
  for(ii in 1:nrow(KSData))
    HarteData[ii,4] = ksn2Harte(KSData[ii, "Key"], KSData[ii, "Chord"])
  write.table(HarteData, "../Harmony/Harte/$1.harte", row.names=FALSE)
EOF
