
source("dataset.R")

imageWidth  = 6  # inches
fontScaling = 0.6

if(exists("allData"))
  rm(allData)
for(filename in dataset)
{
  cat(filename, "\n")
  currentData = read.table(paste("../../Harmony/CSV/", filename, ".csv", sep=""), header=TRUE)
  if(exists("allData"))
    allData = rbind(allData, currentData)
  else
    allData = currentData
}

cat("Loaded", nrow(allData), "harmony labels\n")

# Scale degree frequency:
pdf("statsDegree.pdf", width=imageWidth, height=3)
par(cex=fontScaling)
barplot(table(allData[, "Degree"]), names.arg=c("Non-chord", "Tonic", "Supertonic", "Mediant", "Subdominant", "Dominant", "Submediant", "Leading tone"), xlab="Scale degree", ylab="Number of occurances")
dev.off()

# Time signature frequency
pdf("statsMeter.pdf", width=imageWidth, height=3)
par(cex=fontScaling)
timeSignatures = paste(round(allData[,"Beats"]/allData[,"Measures"]), round(96*allData[,"Beats"]/allData[,"Ticks"]), sep="/")
barplot(table(factor(timeSignatures, levels=c("2/2", "3/4", "4/4", "2/4", "6/8", "12/8", "4/2", "9/8", "6/4", "5/4", "3/2"))), xlab="Meter", ylab="Number of occurances")
dev.off()

# Chord label length (in beats)
pdf("statsBeats.pdf", width=imageWidth, height=3)
par(cex=fontScaling)
beatLabels = c(0.125, 0.25, NA, 0.5, rep(NA,3), 1, rep(NA,3), 1.5, rep(NA,3), 2, rep(NA,7), 3, rep(NA,7), 4, rep(NA, 8*44))
barplot(table(factor(allData[,"Beats"], levels=seq(0.125,48, by=0.125))), log="x", names.arg=beatLabels, xlab="Chord duration [beats]", ylab="Number of occurances")
dev.off()

# Key signature frequency
pitchNamesSharp = c("C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B")
pitchNamesFlat  = c("C", "Db", "D", "Eb", "E", "F", "Gb", "G", "Ab", "A", "Bb", "B")
tonalCenters = .keySignatures[as.matrix(cbind(2 - allData[,"Mode"], allData[,"Signature"] + 8))]
tonicNames     = rbind(pitchNamesFlat[tonalCenters + 1], pitchNamesSharp[tonalCenters + 1])
whichMinor = which(allData[,"Mode"] == 0)
whichMajor = which(allData[,"Mode"] == 1)
keyNamesMinor = paste(tonicNames[as.matrix(cbind((allData[whichMinor, "Signature"] >= 0) + 1, whichMinor))], "min", sep="-")
keyNamesMajor = paste(tonicNames[as.matrix(cbind((allData[whichMajor, "Signature"] >= 0) + 1, whichMajor))], "maj", sep="-")
pdf("statsMajorKeys.pdf", width=imageWidth, height=3)
par(cex=fontScaling)
barplot(table(factor(keyNamesMajor, levels=paste(c("Fb", "Cb", "Gb", "Db", "Ab", "Eb", "Bb", "F", "C", "G", "D", "A", "E", "B", "F#", "C#", "G#"), "maj", sep="-"))), las=2, ylab="Number of occurances", xlab="Major scale", ylim=c(0, 3000))
dev.off()
pdf("statsMinorKeys.pdf", width=imageWidth, height=3)
par(cex=fontScaling)
barplot(table(factor(keyNamesMinor, levels=paste(c("Db", "Ab", "Eb", "Bb", "F", "C", "G", "D", "A", "E", "B", "F#", "C#", "G#", "D#", "A#", "E#"), "min", sep="-"))), las=2, ylab="Number of occurances", xlab="Minor scale", ylim=c(0, 3000))
dev.off()

